@@ -2,7 +2,7 @@
 
 class Enigma_EnigmaEngine extends PHPUnit\Framework\TestCase
 {
-    static function setUpBeforeClass()
+    static function setUpBeforeClass(): void
     {
         include_once __DIR__ . '/../enigma.php';
         include_once __DIR__ . '/../lib/enigma_engine.php';
